2021-11-02 Version: 2.0.1
- Fixed useless variables.

2021-03-31 Version: 2.0.0
- Generated python 2020-01-16 for DAS.

2020-11-30 Version: 1.1.0
- Support new API GetAutonomousNotifyEvents and GetAutonomousNotifyEventDetail.

